dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/pci.h b/include/pci.h
index a8472dd..d5b42ce 100644
--- a/include/pci.h
+++ b/include/pci.h
@@ -899,7 +899,7 @@
 
 #ifdef CONFIG_DM_PCI
 /**
  * struct pci_child_platdata - information stored about each PCI device
  *
  * Every device on a PCI bus has this per-child data.
  *
@@ -914,7 +914,7 @@
  * @pfdev:	Handle to Physical Function device
  * @virtid:	Virtual Function Index
  */
-struct pci_child_platdata {
+struct pci_child_plat {
 	int devfn;
 	unsigned short vendor;
 	unsigned short device;
@@ -899,7 +899,7 @@
 #ifdef CONFIG_DM_PCI
 /**
- * struct pci_child_platdata - information stored about each PCI device
+ * struct pci_child_plat - information stored about each PCI device
  *
  * Every device on a PCI bus has this per-child data.